@@ -111,12 +111,15 @@ handle_memory_finished_cb (EphyAboutHandler       *handler,
     g_string_append_printf (data_str, "<head><title>%s</title>"
                             "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"
                             "<link href=\""EPHY_PAGE_TEMPLATE_ABOUT_CSS "\" rel=\"stylesheet\" type=\"text/css\">"
-                            "</head><body>",
+                            "</head><body>"
+                            "<div id='memory'>",
                             _("Memory usage"));
 
     g_string_append_printf (data_str, "<h1>%s</h1>", _("Memory usage"));
     g_string_append (data_str, memory);
     g_free (memory);
+
+    g_string_append (data_str, "</div>");
   }
 
   g_string_append (data_str, "</html>");
@@ -173,6 +176,7 @@ ephy_about_handler_handle_about (EphyAboutHandler       *handler,
                           "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"
                           "<link href=\""EPHY_PAGE_TEMPLATE_ABOUT_CSS "\" rel=\"stylesheet\" type=\"text/css\">"
                           "</head><body>"
+                          "<div id=\"about-app\">"
                           "<div class=\"dialog\">"
                           "<img id=\"about-icon\" src=\"file://%s\"/>"
                           "<h1 id=\"about-title\">%s</h1>"
@@ -181,13 +185,13 @@ ephy_about_handler_handle_about (EphyAboutHandler       *handler,
                           "<table class=\"properties\">"
                           "<tr><td class=\"prop-label\">%s</td><td class=\"prop-value\">%d.%d.%d</td></tr>"
                           "</table>"
-                          "</div></body></html>",
+                          "</div></div></body></html>",
                           _("About Web"),
                           icon_info ? gtk_icon_info_get_filename (icon_info) : "",
 #if !TECH_PREVIEW
-                         _("Web"),
+                          _("Web"),
 #else
-                         _("Epiphany Technology Preview"),
+                          _("Epiphany Technology Preview"),
 #endif
                           version,
                           _("A simple, clean, beautiful view of the web"),
@@ -249,7 +253,7 @@ handle_applications_finished_cb (EphyAboutHandler       *handler,
                             "    row.parentNode.removeChild(row);"
                             "  }"
                             "</script>"
-                            "</head><body class=\"applications-body\"><h1>%s</h1>"
+                            "</head><div id=\"applications\"><body class=\"applications-body\"><h1>%s</h1>"
                             "<p>%s</p>",
                             _("Applications"),
                             _("Applications"),
@@ -271,9 +275,9 @@ handle_applications_finished_cb (EphyAboutHandler       *handler,
                               _("Installed on:"), app->install_date);
     }
 
-    g_string_append (data_str, "</table></body></html>");
+    g_string_append (data_str, "</table></div></body></html>");
   } else {
-    g_autoptr(GtkIconInfo) icon_info = NULL;
+    g_autoptr (GtkIconInfo) icon_info = NULL;
     g_autofree gchar *icon = g_strconcat ("application-x-addon-symbolic", NULL);
 
     g_string_append_printf (data_str, "<html><head><title>%s</title>"
@@ -295,7 +299,7 @@ handle_applications_finished_cb (EphyAboutHandler       *handler,
                             "</body></html>\n",
                             icon_info ? gtk_icon_info_get_filename (icon_info) : "",
                             /* Displayed when opening applications without any installed web apps. */
-                            _("Applications"), _("You can add your favorite website by clicking <b>Install Site as Web Application…</b> within page menu."));
+                            _("Applications"), _("You can add your favorite website by clicking <b>Install Site as Web Application…</b> within the page menu."));
   }
 
   ephy_web_application_free_application_list (applications);
@@ -393,10 +397,14 @@ history_service_query_urls_cb (EphyHistoryService     *history,
   g_string_append (data_str,
                    "<div id=\"overview\">\n");
 
+  g_string_append (data_str,
+                   "<div id=\"most-visited-grid\">\n");
+
   for (l = urls; l; l = g_list_next (l)) {
     EphyHistoryURL *url = (EphyHistoryURL *)l->data;
     const char *snapshot;
-    char *thumbnail_style = NULL;
+    g_autofree char *thumbnail_style = NULL;
+    g_autofree char *markup = NULL;
 
     snapshot = ephy_snapshot_service_lookup_cached_snapshot_path (snapshot_service, url->url);
     if (snapshot)
@@ -404,22 +412,23 @@ history_service_query_urls_cb (EphyHistoryService     *history,
     else
       ephy_embed_shell_schedule_thumbnail_update (shell, url);
 
+    markup = g_markup_escape_text (url->title, -1);
     g_string_append_printf (data_str,
                             "<a class=\"overview-item\" title=\"%s\" href=\"%s\">"
-                            "  <div class=\"overview-close-button\" title=\"%s\">&#10006;</div>"
+                            "  <div class=\"overview-close-button\" title=\"%s\"></div>"
                             "  <span class=\"overview-thumbnail\"%s></span>"
                             "  <span class=\"overview-title\">%s</span>"
                             "</a>",
-                            g_markup_escape_text (url->title, -1), url->url, _("Remove from overview"),
+                            markup, url->url, _("Remove from overview"),
                             thumbnail_style ? thumbnail_style : "", url->title);
-    g_free (thumbnail_style);
   }
 
   data_str = g_string_append (data_str,
+                              "  </div>\n"
                               "  </div>\n"
                               "</body></html>\n");
 
- out:
+out:
   data_length = data_str->len;
   ephy_about_handler_finish_request (request, g_string_free (data_str, FALSE), data_length);
   g_object_unref (request);
