@@ -29,7 +29,6 @@
 #include "ephy-embed-prefs.h"
 #include "ephy-embed-shell.h"
 #include "ephy-embed-utils.h"
-#include "ephy-evince-document-view.h"
 #include "ephy-find-toolbar.h"
 #include "ephy-notification-container.h"
 #include "ephy-prefs.h"
@@ -66,7 +65,6 @@ struct _EphyEmbed {
   GtkWidget *floating_bar;
   GtkWidget *progress;
   GtkWidget *fullscreen_message_label;
-  GtkWidget *document_view;
 
   char *title;
   WebKitURIRequest *delayed_request;
@@ -76,8 +74,6 @@ struct _EphyEmbed {
   GSList *messages;
   GSList *keys;
 
-  EphyEmbedMode mode;
-
   guint seq_context_id;
   guint seq_message_id;
 
@@ -136,7 +132,8 @@ static GParamSpec *obj_properties[LAST_PROP];
  */
 
 static guint
-ephy_embed_statusbar_get_context_id (EphyEmbed *embed, const char  *context_description)
+ephy_embed_statusbar_get_context_id (EphyEmbed  *embed,
+                                     const char *context_description)
 {
   char *string;
   guint id;
@@ -159,7 +156,8 @@ ephy_embed_statusbar_get_context_id (EphyEmbed *embed, const char  *context_desc
 }
 
 static void
-ephy_embed_set_statusbar_label (EphyEmbed *embed, const char *label)
+ephy_embed_set_statusbar_label (EphyEmbed  *embed,
+                                const char *label)
 {
   nautilus_floating_bar_set_primary_label (NAUTILUS_FLOATING_BAR (embed->floating_bar), label);
 
@@ -171,7 +169,8 @@ ephy_embed_set_statusbar_label (EphyEmbed *embed, const char *label)
 }
 
 static void
-ephy_embed_statusbar_update (EphyEmbed *embed, const char *text)
+ephy_embed_statusbar_update (EphyEmbed  *embed,
+                             const char *text)
 {
   g_assert (EPHY_IS_EMBED (embed));
 
@@ -179,7 +178,9 @@ ephy_embed_statusbar_update (EphyEmbed *embed, const char *text)
 }
 
 static guint
-ephy_embed_statusbar_push (EphyEmbed *embed, guint context_id, const char *text)
+ephy_embed_statusbar_push (EphyEmbed  *embed,
+                           guint       context_id,
+                           const char *text)
 {
   EphyEmbedStatusbarMsg *msg;
 
@@ -202,7 +203,8 @@ ephy_embed_statusbar_push (EphyEmbed *embed, guint context_id, const char *text)
 /* End of code based on GTK+ GtkStatusbar. */
 
 static void
-ephy_embed_statusbar_pop (EphyEmbed *embed, guint context_id)
+ephy_embed_statusbar_pop (EphyEmbed *embed,
+                          guint      context_id)
 {
   EphyEmbedStatusbarMsg *msg;
   GSList *list;
@@ -227,7 +229,8 @@ ephy_embed_statusbar_pop (EphyEmbed *embed, guint context_id)
 }
 
 static void
-remove_from_destroy_list_cb (GtkWidget *widget, EphyEmbed *embed)
+remove_from_destroy_list_cb (GtkWidget *widget,
+                             EphyEmbed *embed)
 {
   GSList *list;
 
@@ -287,9 +290,9 @@ web_view_title_changed_cb (WebKitWebView *web_view,
 }
 
 static void
-load_changed_cb (WebKitWebView  *web_view,
-                 WebKitLoadEvent load_event,
-                 EphyEmbed      *embed)
+load_changed_cb (WebKitWebView   *web_view,
+                 WebKitLoadEvent  load_event,
+                 EphyEmbed       *embed)
 {
   switch (load_event) {
     case WEBKIT_LOAD_COMMITTED:
@@ -540,7 +543,7 @@ ephy_embed_attach_inspector_cb (WebKitWebInspector *inspector,
 
 static gboolean
 ephy_embed_close_inspector_cb (WebKitWebInspector *inspector,
-                                EphyEmbed          *embed)
+                               EphyEmbed          *embed)
 {
   embed->inspector_loaded = FALSE;
 
@@ -587,7 +590,9 @@ pop_statusbar_later_cb (gpointer data)
 }
 
 static void
-status_message_notify_cb (EphyWebView *view, GParamSpec *pspec, EphyEmbed *embed)
+status_message_notify_cb (EphyWebView *view,
+                          GParamSpec  *pspec,
+                          EphyEmbed   *embed)
 {
   const char *message;
 
@@ -603,7 +608,7 @@ status_message_notify_cb (EphyWebView *view, GParamSpec *pspec, EphyEmbed *embed
     ephy_embed_statusbar_push (embed, embed->tab_message_id, message);
   } else {
     /* A short timeout before hiding the statusbar ensures that while moving
-       over a series of links, the overlay widget doesn't flicker on and off. */
+     *  over a series of links, the overlay widget doesn't flicker on and off. */
     if (embed->pop_statusbar_later_source_id == 0) {
       embed->pop_statusbar_later_source_id = g_timeout_add (250, pop_statusbar_later_cb, embed);
       g_source_set_name_by_id (embed->pop_statusbar_later_source_id, "[epiphany] pop_statusbar_later_cb");
@@ -621,7 +626,9 @@ clear_progress_cb (EphyEmbed *embed)
 }
 
 static void
-progress_update (EphyWebView *view, GParamSpec *pspec, EphyEmbed *embed)
+progress_update (EphyWebView *view,
+                 GParamSpec  *pspec,
+                 EphyEmbed   *embed)
 {
   gdouble progress;
   gboolean loading;
@@ -702,7 +709,8 @@ ephy_embed_maybe_load_delayed_request (EphyEmbed *embed)
 }
 
 static void
-ephy_embed_restored_window_cb (EphyEmbedShell *shell, EphyEmbed *embed)
+ephy_embed_restored_window_cb (EphyEmbedShell *shell,
+                               EphyEmbed      *embed)
 {
   if (!gtk_widget_get_mapped (GTK_WIDGET (embed)))
     return;
@@ -711,7 +719,8 @@ ephy_embed_restored_window_cb (EphyEmbedShell *shell, EphyEmbed *embed)
 }
 
 static void
-ephy_embed_mapped_cb (GtkWidget *widget, gpointer data)
+ephy_embed_mapped_cb (GtkWidget *widget,
+                      gpointer   data)
 {
   ephy_embed_maybe_load_delayed_request ((EphyEmbed *)widget);
 }
@@ -820,7 +829,7 @@ ephy_embed_constructed (GObject *object)
     info_bar = gtk_info_bar_new ();
     gtk_info_bar_set_message_type (GTK_INFO_BAR (info_bar), GTK_MESSAGE_INFO);
     /* Translators: this means WebDriver control. */
-    label = gtk_label_new (_("Web is being controlled by automation"));
+    label = gtk_label_new (_("Web is being controlled by automation."));
     gtk_box_pack_start (GTK_BOX (gtk_info_bar_get_content_area (GTK_INFO_BAR (info_bar))), label, FALSE, FALSE, 0);
     gtk_widget_show (label);
 
@@ -915,7 +924,8 @@ ephy_embed_add_top_widget (EphyEmbed                *embed,
  * details.
  */
 void
-ephy_embed_remove_top_widget (EphyEmbed *embed, GtkWidget *widget)
+ephy_embed_remove_top_widget (EphyEmbed *embed,
+                              GtkWidget *widget)
 {
   if (g_slist_find (embed->destroy_on_transition_list, widget)) {
     GSList *list;
@@ -940,7 +950,9 @@ ephy_embed_remove_top_widget (EphyEmbed *embed, GtkWidget *widget)
  * is on is switched to.
  */
 void
-ephy_embed_set_delayed_load_request (EphyEmbed *embed, WebKitURIRequest *request, WebKitWebViewSessionState *state)
+ephy_embed_set_delayed_load_request (EphyEmbed                 *embed,
+                                     WebKitURIRequest          *request,
+                                     WebKitWebViewSessionState *state)
 {
   g_assert (EPHY_IS_EMBED (embed));
   g_assert (WEBKIT_IS_URI_REQUEST (request));
@@ -1022,61 +1034,3 @@ ephy_embed_detach_notification_container (EphyEmbed *embed)
     gtk_container_remove (GTK_CONTAINER (embed->overlay), g_object_ref (GTK_WIDGET (container)));
   }
 }
-
-void
-ephy_embed_set_mode (EphyEmbed *embed, EphyEmbedMode mode)
-{
-  g_assert (EPHY_IS_EMBED (embed));
-
-  if (embed->mode == mode)
-    return;
-
-  switch (mode) {
-  case EPHY_EMBED_MODE_WEB_VIEW:
-    if (embed->document_view != NULL) {
-      gtk_widget_destroy (embed->document_view);
-      embed->document_view = NULL;
-    }
-    gtk_widget_set_visible (GTK_WIDGET (embed->paned), TRUE);
-    break;
-  case EPHY_EMBED_MODE_EVINCE_DOCUMENT:
-    gtk_widget_set_visible (GTK_WIDGET (embed->paned), FALSE);
-    embed->document_view = ephy_evince_document_view_new ();
-    ephy_evince_document_set_embed (EPHY_EVINCE_DOCUMENT_VIEW (embed->document_view), embed);
-    gtk_box_pack_start (GTK_BOX (embed),
-                        embed->document_view,
-                        TRUE, TRUE, 0);
-    gtk_widget_show_all (embed->document_view);
-    break;
-  }
-
-  embed->mode = mode;
-}
-
-EphyEmbedMode
-ephy_embed_get_mode (EphyEmbed *embed)
-{
-  return embed->mode;
-}
-
-static void
-document_download_finished_cb (WebKitDownload *download,
-                               EphyEmbed      *embed)
-{
-  const char *document_uri = webkit_download_get_destination (download);
-
-  ephy_evince_document_view_load_uri (EPHY_EVINCE_DOCUMENT_VIEW (embed->document_view),
-                                      document_uri);
-}
-
-void
-ephy_embed_download_started (EphyEmbed    *embed,
-                             EphyDownload *ephy_download)
-{
-  WebKitDownload *download = ephy_download_get_webkit_download (ephy_download);
-
-  if (embed->mode == EPHY_EMBED_MODE_EVINCE_DOCUMENT) {
-    ephy_download_enable_evince_document_mode (ephy_download);
-    g_signal_connect (download, "finished", G_CALLBACK (document_download_finished_cb), embed);
-  }
-}
