@@ -85,7 +85,8 @@ typedef enum {
 
 /* private functions */
 
-static void ephy_find_toolbar_set_web_view (EphyFindToolbar *toolbar, WebKitWebView *web_view);
+static void ephy_find_toolbar_set_web_view (EphyFindToolbar *toolbar,
+                                            WebKitWebView   *web_view);
 
 static void
 update_search_tag (EphyFindToolbar *toolbar)
@@ -153,8 +154,8 @@ clear_status (EphyFindToolbar *toolbar)
 }
 
 static void
-real_find (EphyFindToolbar  *toolbar,
-           EphyFindDirection direction)
+real_find (EphyFindToolbar   *toolbar,
+           EphyFindDirection  direction)
 {
   WebKitFindOptions options = WEBKIT_FIND_OPTIONS_CASE_INSENSITIVE;
 
@@ -164,8 +165,8 @@ real_find (EphyFindToolbar  *toolbar,
   if (direction == EPHY_FIND_DIRECTION_PREV)
     options |= WEBKIT_FIND_OPTIONS_BACKWARDS;
 
-  webkit_find_controller_search (toolbar->controller, toolbar->find_string, options, G_MAXUINT);
   webkit_find_controller_count_matches (toolbar->controller, toolbar->find_string, options, G_MAXUINT);
+  webkit_find_controller_search (toolbar->controller, toolbar->find_string, options, G_MAXUINT);
 }
 
 static gboolean
@@ -261,6 +262,10 @@ entry_key_press_event_cb (GtkEntry        *entry,
               event->keyval == GDK_KEY_KP_Enter ||
               event->keyval == GDK_KEY_ISO_Enter)) {
     handled = ephy_find_toolbar_activate_link (toolbar, event->state);
+  } else if ((event->state & mask) == GDK_CONTROL_MASK &&
+             (event->keyval == GDK_KEY_g)) {
+    handled = TRUE;
+    ephy_find_toolbar_find_next (toolbar);
   } else if ((event->state & mask) == GDK_SHIFT_MASK &&
              (event->keyval == GDK_KEY_Return ||
               event->keyval == GDK_KEY_KP_Enter ||
