@@ -27,22 +27,22 @@
 #include "ephy-bookmarks-manager.h"
 #include "ephy-debug.h"
 #include "ephy-shell.h"
+#include "ephy-window.h"
 
 #include <glib/gi18n.h>
 
 struct _EphyBookmarksPopover {
-  GtkPopover             parent_instance;
+  GtkPopover parent_instance;
 
-  GtkWidget             *toplevel_stack;
-  GtkWidget             *bookmarks_list_box;
-  GtkWidget             *tags_list_box;
-  GtkWidget             *tag_detail_list_box;
-  GtkWidget             *tag_detail_back_button;
-  GtkWidget             *tag_detail_label;
-  char                  *tag_detail_tag;
+  GtkWidget *toplevel_stack;
+  GtkWidget *bookmarks_list_box;
+  GtkWidget *tags_list_box;
+  GtkWidget *tag_detail_list_box;
+  GtkWidget *tag_detail_back_button;
+  GtkWidget *tag_detail_label;
+  char *tag_detail_tag;
 
-  EphyBookmarksManager  *manager;
-  EphyWindow            *window;
+  EphyBookmarksManager *manager;
 };
 
 G_DEFINE_TYPE (EphyBookmarksPopover, ephy_bookmarks_popover, GTK_TYPE_POPOVER)
@@ -50,17 +50,30 @@ G_DEFINE_TYPE (EphyBookmarksPopover, ephy_bookmarks_popover, GTK_TYPE_POPOVER)
 #define EPHY_LIST_BOX_ROW_TYPE_BOOKMARK "bookmark"
 #define EPHY_LIST_BOX_ROW_TYPE_TAG "tag"
 
-enum {
-  PROP_0,
-  PROP_WINDOW,
-  LAST_PROP
-};
-
-static GParamSpec *obj_properties[LAST_PROP];
-
-static GtkWidget *create_bookmark_row (gpointer item, gpointer user_data);
+static GtkWidget * create_bookmark_row (gpointer item, gpointer user_data);
 static GtkWidget *create_tag_row (const char *tag);
 
+static void
+remove_bookmark_row_from_container (GtkContainer *container,
+                                    const char   *url)
+{
+  GList *children;
+
+  g_assert (GTK_IS_CONTAINER (container));
+
+  children = gtk_container_get_children (container);
+  for (GList *l = children; l && l->data; l = l->next) {
+    const char *type = g_object_get_data (l->data, "type");
+
+    if (g_strcmp0 (type, EPHY_LIST_BOX_ROW_TYPE_BOOKMARK) == 0 &&
+        g_strcmp0 (ephy_bookmark_row_get_bookmark_url (l->data), url) == 0) {
+      gtk_container_remove (container, l->data);
+      break;
+    }
+  }
+  g_list_free (children);
+}
+
 static void
 ephy_bookmarks_popover_bookmark_tag_added_cb (EphyBookmarksPopover *self,
                                               EphyBookmark         *bookmark,
@@ -68,39 +81,48 @@ ephy_bookmarks_popover_bookmark_tag_added_cb (EphyBookmarksPopover *self,
                                               EphyBookmarksManager *manager)
 {
   GtkWidget *tag_row;
+  GList *children;
+  GList *l;
+  gboolean exists;
+  const char *visible_stack_child;
+  const char *title;
+  const char *type;
 
   g_assert (EPHY_IS_BOOKMARK (bookmark));
   g_assert (EPHY_IS_BOOKMARKS_POPOVER (self));
 
   /* If the bookmark no longer has 0 tags, we remove it from the tags list box */
-  if (g_sequence_get_length (ephy_bookmark_get_tags (bookmark)) == 1) {
-    GList *children;
-    GList *l;
-    const char *visible_stack_child;
+  if (g_sequence_get_length (ephy_bookmark_get_tags (bookmark)) == 1)
+    remove_bookmark_row_from_container (GTK_CONTAINER (self->tags_list_box),
+                                        ephy_bookmark_get_url (bookmark));
 
-    children = gtk_container_get_children (GTK_CONTAINER (self->tags_list_box));
-    for (l = children; l != NULL; l = l->next) {
-      const char *url;
+  /* If we are on the tag detail list box, then the user has toggled the state
+   * of the tag widget multiple times. The first time the bookmark was removed
+   * from the list box. Now we have to add it back. */
+  visible_stack_child = gtk_stack_get_visible_child_name (GTK_STACK (self->toplevel_stack));
+  if (g_strcmp0 (visible_stack_child, "tag_detail") == 0 &&
+      g_strcmp0 (self->tag_detail_tag, tag) == 0) {
+    GtkWidget *row;
 
-      url = g_object_get_data (G_OBJECT (l->data), "url");
-      if (g_strcmp0 (ephy_bookmark_get_url (bookmark), url) == 0)
-        gtk_container_remove (GTK_CONTAINER (self->tags_list_box), GTK_WIDGET (l->data));
-    }
-
-    /* If we are on the tag detail list box, then the user has toggled the state
-     * of the tag widget multiple times. The first time the bookmark was removed
-     * from the list box. Now we have to add it back. */
-    visible_stack_child = gtk_stack_get_visible_child_name (GTK_STACK (self->toplevel_stack));
-    if (g_strcmp0 (visible_stack_child, "tag_detail") == 0) {
-      GtkWidget *row;
-      row = create_bookmark_row (bookmark, self);
-      gtk_container_add (GTK_CONTAINER (self->tag_detail_list_box), row);
-    }
+    row = create_bookmark_row (bookmark, self);
+    gtk_container_add (GTK_CONTAINER (self->tag_detail_list_box), row);
   }
 
-  /* The first time a tag is assigned to a bookmark, a tag row is created and
-   * added to the tags list */
-  if (g_sequence_get_length (ephy_bookmarks_manager_get_bookmarks_with_tag (manager, tag)) == 1) {
+  exists = FALSE;
+  children = gtk_container_get_children (GTK_CONTAINER (self->tags_list_box));
+  for (l = children; l != NULL; l = l->next) {
+    title = g_object_get_data (G_OBJECT (l->data), "title");
+    type = g_object_get_data (G_OBJECT (l->data), "type");
+
+    if (g_strcmp0 (title, tag) == 0 &&
+        g_strcmp0 (type, EPHY_LIST_BOX_ROW_TYPE_TAG) == 0) {
+      exists = TRUE;
+      break;
+    }
+  }
+  g_list_free (children);
+
+  if (!exists) {
     tag_row = create_tag_row (tag);
     gtk_container_add (GTK_CONTAINER (self->tags_list_box), tag_row);
   }
@@ -128,14 +150,18 @@ ephy_bookmarks_popover_bookmark_tag_removed_cb (EphyBookmarksPopover *self,
     exists = FALSE;
     children = gtk_container_get_children (GTK_CONTAINER (self->tags_list_box));
     for (l = children; l != NULL; l = l->next) {
-      const char *url;
+      const char *type = g_object_get_data (l->data, "type");
 
-      url = g_object_get_data (G_OBJECT(l->data), "url");
-      if (g_strcmp0 (ephy_bookmark_get_url (bookmark), url) == 0) {
-        exists = TRUE;
-        break;
+      if (g_strcmp0 (type, EPHY_LIST_BOX_ROW_TYPE_BOOKMARK) == 0) {
+        const char *url = ephy_bookmark_row_get_bookmark_url (l->data);
+
+        if (g_strcmp0 (ephy_bookmark_get_url (bookmark), url) == 0) {
+          exists = TRUE;
+          break;
+        }
       }
     }
+    g_list_free (children);
 
     if (!exists) {
       row = create_bookmark_row (bookmark, self);
@@ -148,14 +174,8 @@ ephy_bookmarks_popover_bookmark_tag_removed_cb (EphyBookmarksPopover *self,
   visible_stack_child = gtk_stack_get_visible_child_name (GTK_STACK (self->toplevel_stack));
   if (g_strcmp0 (visible_stack_child, "tag_detail") == 0 &&
       g_strcmp0 (self->tag_detail_tag, tag) == 0) {
-    children = gtk_container_get_children (GTK_CONTAINER (self->tag_detail_list_box));
-    for (l = children; l != NULL; l = l->next) {
-      const char *url;
-
-      url = g_object_get_data (G_OBJECT (l->data), "url");
-      if (g_strcmp0 (ephy_bookmark_get_url (bookmark), url) == 0)
-        gtk_container_remove (GTK_CONTAINER (self->tag_detail_list_box), GTK_WIDGET (l->data));
-    }
+    remove_bookmark_row_from_container (GTK_CONTAINER (self->tag_detail_list_box),
+                                        ephy_bookmark_get_url (bookmark));
 
     /* If we removed the tag's last bookmark, switch back to the tags list. */
     if (g_sequence_is_empty (ephy_bookmarks_manager_get_bookmarks_with_tag (self->manager, tag))) {
@@ -170,12 +190,13 @@ ephy_bookmarks_popover_bookmark_tag_removed_cb (EphyBookmarksPopover *self,
 
   /* If the tag no longer contains bookmarks, remove it from the tags list */
   if (g_sequence_is_empty (ephy_bookmarks_manager_get_bookmarks_with_tag (self->manager, tag))) {
-      children = gtk_container_get_children (GTK_CONTAINER (self->tags_list_box));
-      for (l = children; l != NULL; l = l->next) {
-        title = g_object_get_data (G_OBJECT (l->data), "title");
-        if (g_strcmp0 (title, tag) == 0)
-          gtk_container_remove (GTK_CONTAINER (self->tags_list_box), GTK_WIDGET (l->data));
-      }
+    children = gtk_container_get_children (GTK_CONTAINER (self->tags_list_box));
+    for (l = children; l != NULL; l = l->next) {
+      title = g_object_get_data (G_OBJECT (l->data), "title");
+      if (g_strcmp0 (title, tag) == 0)
+        gtk_container_remove (GTK_CONTAINER (self->tags_list_box), GTK_WIDGET (l->data));
+    }
+    g_list_free (children);
   }
 }
 
@@ -193,9 +214,6 @@ create_bookmark_row (gpointer item,
   g_object_set_data_full (G_OBJECT (row), "title",
                           g_strdup (ephy_bookmark_get_title (bookmark)),
                           (GDestroyNotify)g_free);
-  g_object_set_data_full (G_OBJECT (row), "url",
-                          g_strdup (ephy_bookmark_get_url (bookmark)),
-                          (GDestroyNotify)g_free);
 
   return row;
 }
@@ -262,50 +280,14 @@ ephy_bookmarks_popover_bookmark_removed_cb (EphyBookmarksPopover *self,
                                             EphyBookmark         *bookmark,
                                             EphyBookmarksManager *manager)
 {
-  GtkWidget *row = NULL;
-  GList *children;
-  GList *l;
-  gboolean found = FALSE;
-
   g_assert (EPHY_IS_BOOKMARKS_POPOVER (self));
   g_assert (EPHY_IS_BOOKMARK (bookmark));
   g_assert (EPHY_IS_BOOKMARKS_MANAGER (manager));
 
-  children = gtk_container_get_children (GTK_CONTAINER (self->tags_list_box));
-  for (l = children; l != NULL; l = l->next) {
-    const char *type;
-    const char *url;
-
-    row = GTK_WIDGET (l->data);
-    type = g_object_get_data (G_OBJECT (row), "type");
-    url = g_object_get_data (G_OBJECT (row), "url");
-    if (g_strcmp0 (type, EPHY_LIST_BOX_ROW_TYPE_BOOKMARK) == 0
-        && g_strcmp0 (ephy_bookmark_get_url (bookmark), url) == 0) {
-      found = TRUE;
-      break;
-    }
-  }
-  if (found) {
-    gtk_container_remove (GTK_CONTAINER (self->tags_list_box), row);
-    found = FALSE;
-  }
-
-  children = gtk_container_get_children (GTK_CONTAINER (self->tag_detail_list_box));
-  for (l = children; l != NULL; l = l->next) {
-    const char *type;
-    const char *url;
-
-    row = GTK_WIDGET (l->data);
-    type = g_object_get_data (G_OBJECT (row), "type");
-    url = g_object_get_data (G_OBJECT (row), "url");
-    if (g_strcmp0 (type, EPHY_LIST_BOX_ROW_TYPE_BOOKMARK) == 0
-        && g_strcmp0 (ephy_bookmark_get_url (bookmark), url) == 0) {
-      found = TRUE;
-      break;
-    }
-  }
-  if (found)
-    gtk_container_remove (GTK_CONTAINER (self->tag_detail_list_box), row);
+  remove_bookmark_row_from_container (GTK_CONTAINER (self->tags_list_box),
+                                      ephy_bookmark_get_url (bookmark));
+  remove_bookmark_row_from_container (GTK_CONTAINER (self->tag_detail_list_box),
+                                      ephy_bookmark_get_url (bookmark));
 
   if (g_list_model_get_n_items (G_LIST_MODEL (self->manager)) == 0) {
     gtk_stack_set_visible_child_name (GTK_STACK (self->toplevel_stack), "empty-state");
@@ -363,7 +345,8 @@ ephy_bookmarks_popover_tag_deleted_cb (EphyBookmarksPopover *self,
 }
 
 static int
-tags_list_box_sort_func (GtkListBoxRow *row1, GtkListBoxRow *row2)
+tags_list_box_sort_func (GtkListBoxRow *row1,
+                         GtkListBoxRow *row2)
 {
   const char *type1;
   const char *type2;
@@ -381,7 +364,7 @@ tags_list_box_sort_func (GtkListBoxRow *row1, GtkListBoxRow *row2)
 
   if (g_strcmp0 (type1, EPHY_LIST_BOX_ROW_TYPE_TAG) == 0
       && g_strcmp0 (type2, EPHY_LIST_BOX_ROW_TYPE_TAG) == 0)
-      return ephy_bookmark_tags_compare (title1, title2);
+    return ephy_bookmark_tags_compare (title1, title2);
 
   if (g_strcmp0 (type1, EPHY_LIST_BOX_ROW_TYPE_TAG) == 0)
     return -1;
@@ -397,17 +380,17 @@ ephy_bookmarks_popover_actions_tag_detail_back (GSimpleAction *action,
                                                 gpointer       user_data)
 {
   EphyBookmarksPopover *self = user_data;
-  GList *l;
+  GList *children;
 
   g_assert (EPHY_IS_BOOKMARKS_POPOVER (self));
 
   gtk_stack_set_visible_child_name (GTK_STACK (self->toplevel_stack),
                                     "default");
 
-  for (l = gtk_container_get_children (GTK_CONTAINER (self->tag_detail_list_box));
-       l != NULL;
-       l = l->next)
+  children = gtk_container_get_children (GTK_CONTAINER (self->tag_detail_list_box));
+  for (GList *l = children; l != NULL; l = l->next)
     gtk_container_remove (GTK_CONTAINER (self->tag_detail_list_box), l->data);
+  g_list_free (children);
 }
 
 static void
@@ -443,9 +426,9 @@ ephy_bookmarks_popover_show_tag_detail (EphyBookmarksPopover *self,
 }
 
 static void
-ephy_bookmarks_popover_list_box_row_activated_cb (EphyBookmarksPopover   *self,
-                                                  GtkListBoxRow          *row,
-                                                  GtkListBox             *box)
+ephy_bookmarks_popover_list_box_row_activated_cb (EphyBookmarksPopover *self,
+                                                  GtkListBoxRow        *row,
+                                                  GtkListBox           *box)
 {
   const char *type;
   const char *tag;
@@ -456,16 +439,18 @@ ephy_bookmarks_popover_list_box_row_activated_cb (EphyBookmarksPopover   *self,
 
   type = g_object_get_data (G_OBJECT (row), "type");
   if (g_strcmp0 (type, EPHY_LIST_BOX_ROW_TYPE_BOOKMARK) == 0) {
-    EphyBookmark *bookmark;
+    GtkWidget *window;
     GActionGroup *action_group;
     GAction *action;
     const char *url;
 
-    action_group = gtk_widget_get_action_group (GTK_WIDGET (self->window), "win");
+    window = gtk_widget_get_ancestor (GTK_WIDGET (self), EPHY_TYPE_WINDOW);
+    g_assert (EPHY_IS_WINDOW (window));
+    action_group = gtk_widget_get_action_group (window, "win");
+    g_assert (action_group != NULL);
     action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "open-bookmark");
-
-    bookmark = ephy_bookmark_row_get_bookmark (EPHY_BOOKMARK_ROW (row));
-    url = ephy_bookmark_get_url (bookmark);
+    g_assert (action != NULL);
+    url = ephy_bookmark_row_get_bookmark_url (EPHY_BOOKMARK_ROW (row));
 
     g_action_activate (action, g_variant_new_string (url));
   } else {
@@ -484,23 +469,6 @@ ephy_bookmarks_popover_finalize (GObject *object)
   G_OBJECT_CLASS (ephy_bookmarks_popover_parent_class)->finalize (object);
 }
 
-static void
-ephy_bookmarks_popover_set_property (GObject      *object,
-                                     guint         prop_id,
-                                     const GValue *value,
-                                     GParamSpec   *pspec)
-{
-  EphyBookmarksPopover *self = EPHY_BOOKMARKS_POPOVER (object);
-
-  switch (prop_id) {
-    case PROP_WINDOW:
-      self->window = g_value_get_object (value);
-      break;
-    default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-  }
-}
-
 static void
 ephy_bookmarks_popover_class_init (EphyBookmarksPopoverClass *klass)
 {
@@ -508,16 +476,6 @@ ephy_bookmarks_popover_class_init (EphyBookmarksPopoverClass *klass)
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   object_class->finalize = ephy_bookmarks_popover_finalize;
-  object_class->set_property = ephy_bookmarks_popover_set_property;
-
-  obj_properties[PROP_WINDOW] =
-    g_param_spec_object ("window",
-                         "An EphyWindow object",
-                         "The popover's parent EphyWindow",
-                         EPHY_TYPE_WINDOW,
-                         G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
-
-  g_object_class_install_properties (object_class, LAST_PROP, obj_properties);
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/epiphany/gtk/bookmarks-popover.ui");
   gtk_widget_class_bind_template_child (widget_class, EphyBookmarksPopover, toplevel_stack);
@@ -622,9 +580,8 @@ ephy_bookmarks_popover_init (EphyBookmarksPopover *self)
 }
 
 EphyBookmarksPopover *
-ephy_bookmarks_popover_new (EphyWindow *window)
+ephy_bookmarks_popover_new (void)
 {
   return g_object_new (EPHY_TYPE_BOOKMARKS_POPOVER,
-                       "window", window,
                        NULL);
 }
