@@ -43,9 +43,9 @@ typedef enum {
 } LinkDestination;
 
 static void
-view_in_destination (EphyWindow     *window,
-                     const char     *property_name,
-                     LinkDestination destination)
+view_in_destination (EphyWindow      *window,
+                     const char      *property_name,
+                     LinkDestination  destination)
 {
   EphyEmbedEvent *event;
   GValue value = { 0, };
@@ -102,7 +102,8 @@ popup_cmd_media_in_new_window (GSimpleAction *action,
 }
 
 static void
-popup_cmd_copy_to_clipboard (EphyWindow *window, const char *text)
+popup_cmd_copy_to_clipboard (EphyWindow *window,
+                             const char *text)
 {
   gtk_clipboard_set_text (gtk_clipboard_get_default (gdk_display_get_default ()),
                           text, -1);
@@ -161,6 +162,7 @@ filename_suggested_cb (EphyDownload        *download,
                                      GTK_FILE_CHOOSER_ACTION_SAVE,
                                      EPHY_FILE_FILTER_NONE);
   gtk_file_chooser_set_do_overwrite_confirmation (dialog, TRUE);
+  gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), g_settings_get_string (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_LAST_DOWNLOAD_DIRECTORY));
 
   sanitized_filename = ephy_sanitize_filename (g_strdup (suggested_filename));
   gtk_file_chooser_set_current_name (dialog, sanitized_filename);
@@ -179,6 +181,7 @@ filename_suggested_cb (EphyDownload        *download,
 
     ephy_downloads_manager_add_download (ephy_embed_shell_get_downloads_manager (ephy_embed_shell_get_default ()),
                                          download);
+    g_settings_set_string (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_LAST_DOWNLOAD_DIRECTORY, gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dialog)));
   } else {
     g_idle_add_full (G_PRIORITY_DEFAULT,
                      (GSourceFunc)cancel_download_idle_cb,
@@ -382,7 +385,7 @@ popup_cmd_search_selection (GSimpleAction *action,
   search_term = g_variant_get_string (parameter, NULL);
   search_url = ephy_embed_utils_autosearch_address (search_term);
   new_embed = ephy_shell_new_tab (ephy_shell_get_default (),
-                                  EPHY_WINDOW (user_data), embed, EPHY_NEW_TAB_APPEND_AFTER);
+                                  EPHY_WINDOW (user_data), embed, EPHY_NEW_TAB_APPEND_AFTER | EPHY_NEW_TAB_JUMP);
   ephy_web_view_load_url (ephy_embed_get_web_view (new_embed), search_url);
   g_free (search_url);
 }
